==> svix-0.84.0.tar.gz: svix-0.84.0/svix/internal/openapi_client/api/integration/v1_integration_list.py <==
import random
from time import sleep
from typing import Any, Dict, Union

import httpx

from ...client import Client
from ...models.http_error import HttpError
from ...models.http_validation_error import HTTPValidationError
from ...models.list_response_integration_out import ListResponseIntegrationOut
from ...types import UNSET, Unset


def _get_kwargs(
    app_id: str,
    *,
    client: Client,
    limit: Union[Unset, None, int] = UNSET,
    iterator: Union[Unset, None, str] = UNSET,
) -> Dict[str, Any]:
    url = "{}/api/v1/app/{app_id}/integration/".format(client.base_url, app_id=app_id)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    params["limit"] = limit

    params["iterator"] = iterator

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> ListResponseIntegrationOut:
    if response.status_code == 401:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 403:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 404:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 409:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 422:
        raise HTTPValidationError(response.json(), response.status_code)
    if response.status_code == 429:
        raise HttpError(response.json(), response.status_code)
    response_200 = ListResponseIntegrationOut.from_dict(response.json())

    return response_200


sleep_time = 0.05
num_retries = 3


def sync_detailed(
    app_id: str,
    *,
    client: Client,
    limit: Union[Unset, None, int] = UNSET,
    iterator: Union[Unset, None, str] = UNSET,
) -> ListResponseIntegrationOut:
    """List Integrations

     List the application's integrations.

    Args:
        app_id (str):  Example: unique-app-identifier.
        limit (Union[Unset, None, int]):
        iterator (Union[Unset, None, str]):  Example: integ_1srOrx2ZWZBpBUvZwXKQmoEYga2.

    Returns:
        ListResponseIntegrationOut
    """

    kwargs = _get_kwargs(
        app_id=app_id,
        client=client,
        limit=limit,
        iterator=iterator,
    )

    kwargs["headers"] = {"svix-req-id": f"{random.getrandbits(32)}", **kwargs["headers"]}

    retry_count = 0
    for retry in range(num_retries):
        response = httpx.request(
            verify=client.verify_ssl,
            **kwargs,
        )
        if response.status_code >= 500 and retry < num_retries:
            retry_count += 1
            kwargs["headers"]["svix-retry-count"] = str(retry_count)
            sleep(sleep_time)
            sleep_time * 2
        else:
            break

    return _parse_response(response=response)


def sync(
    app_id: str,
    *,
    client: Client,
    limit: Union[Unset, None, int] = UNSET,
    iterator: Union[Unset, None, str] = UNSET,
) -> ListResponseIntegrationOut:
    """List Integrations

     List the application's integrations.

    Args:
        app_id (str):  Example: unique-app-identifier.
        limit (Union[Unset, None, int]):
        iterator (Union[Unset, None, str]):  Example: integ_1srOrx2ZWZBpBUvZwXKQmoEYga2.

    Returns:
        ListResponseIntegrationOut
    """

    return sync_detailed(
        app_id=app_id,
        client=client,
        limit=limit,
        iterator=iterator,
    )


async def asyncio_detailed(
    app_id: str,
    *,
    client: Client,
    limit: Union[Unset, None, int] = UNSET,
    iterator: Union[Unset, None, str] = UNSET,
) -> ListResponseIntegrationOut:
    """List Integrations

     List the application's integrations.

    Args:
        app_id (str):  Example: unique-app-identifier.
        limit (Union[Unset, None, int]):
        iterator (Union[Unset, None, str]):  Example: integ_1srOrx2ZWZBpBUvZwXKQmoEYga2.

    Returns:
        ListResponseIntegrationOut
    """

    kwargs = _get_kwargs(
        app_id=app_id,
        client=client,
        limit=limit,
        iterator=iterator,
    )

    kwargs["headers"] = {"svix-req-id": f"{random.getrandbits(32)}", **kwargs["headers"]}

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        retry_count = 0
        for retry in range(num_retries):
            response = await _client.request(**kwargs)
            if response.status_code >= 500 and retry < num_retries:
                retry_count += 1
                kwargs["headers"]["svix-retry-count"] = str(retry_count)
                sleep(sleep_time)
                sleep_time * 2
            else:
                break

    return _parse_response(response=response)


async def asyncio(
    app_id: str,
    *,
    client: Client,
    limit: Union[Unset, None, int] = UNSET,
    iterator: Union[Unset, None, str] = UNSET,
) -> ListResponseIntegrationOut:
    """List Integrations

     List the application's integrations.

    Args:
        app_id (str):  Example: unique-app-identifier.
        limit (Union[Unset, None, int]):
        iterator (Union[Unset, None, str]):  Example: integ_1srOrx2ZWZBpBUvZwXKQmoEYga2.

    Returns:
        ListResponseIntegrationOut
    """

    return await asyncio_detailed(
        app_id=app_id,
        client=client,
        limit=limit,
        iterator=iterator,
    )

==> svix-0.85.1.tar.gz: svix-0.85.1/svix/internal/openapi_client/api/integration/v1_integration_list.py <==
import random
from time import sleep
from typing import Any, Dict, Union

import httpx

from ...client import AuthenticatedClient
from ...models.http_error import HttpError
from ...models.http_validation_error import HTTPValidationError
from ...models.list_response_integration_out import ListResponseIntegrationOut
from ...types import UNSET, Unset


def _get_kwargs(
    app_id: str,
    *,
    client: AuthenticatedClient,
    limit: Union[Unset, None, int] = UNSET,
    iterator: Union[Unset, None, str] = UNSET,
) -> Dict[str, Any]:
    url = "{}/api/v1/app/{app_id}/integration/".format(client.base_url, app_id=app_id)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    params["limit"] = limit

    params["iterator"] = iterator

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> ListResponseIntegrationOut:
    if response.status_code == 401:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 403:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 404:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 409:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 422:
        raise HTTPValidationError(response.json(), response.status_code)
    if response.status_code == 429:
        raise HttpError(response.json(), response.status_code)
    response_200 = ListResponseIntegrationOut.from_dict(response.json())

    return response_200


sleep_time = 0.05
num_retries = 3


def sync_detailed(
    app_id: str,
    *,
    client: AuthenticatedClient,
    limit: Union[Unset, None, int] = UNSET,
    iterator: Union[Unset, None, str] = UNSET,
) -> ListResponseIntegrationOut:
    """List Integrations

     List the application's integrations.

    Args:
        app_id (str): The app's ID or UID Example: unique-app-identifier.
        limit (Union[Unset, None, int]):
        iterator (Union[Unset, None, str]): The integ's ID Example:
            integ_1srOrx2ZWZBpBUvZwXKQmoEYga2.

    Returns:
        ListResponseIntegrationOut
    """

    kwargs = _get_kwargs(
        app_id=app_id,
        client=client,
        limit=limit,
        iterator=iterator,
    )

    kwargs["headers"] = {"svix-req-id": f"{random.getrandbits(32)}", **kwargs["headers"]}

    retry_count = 0
    for retry in range(num_retries):
        response = httpx.request(
            verify=client.verify_ssl,
            **kwargs,
        )
        if response.status_code >= 500 and retry < num_retries:
            retry_count += 1
            kwargs["headers"]["svix-retry-count"] = str(retry_count)
            sleep(sleep_time)
            sleep_time * 2
        else:
            break

    return _parse_response(response=response)


def sync(
    app_id: str,
    *,
    client: AuthenticatedClient,
    limit: Union[Unset, None, int] = UNSET,
    iterator: Union[Unset, None, str] = UNSET,
) -> ListResponseIntegrationOut:
    """List Integrations

     List the application's integrations.

    Args:
        app_id (str): The app's ID or UID Example: unique-app-identifier.
        limit (Union[Unset, None, int]):
        iterator (Union[Unset, None, str]): The integ's ID Example:
            integ_1srOrx2ZWZBpBUvZwXKQmoEYga2.

    Returns:
        ListResponseIntegrationOut
    """

    return sync_detailed(
        app_id=app_id,
        client=client,
        limit=limit,
        iterator=iterator,
    )


async def asyncio_detailed(
    app_id: str,
    *,
    client: AuthenticatedClient,
    limit: Union[Unset, None, int] = UNSET,
    iterator: Union[Unset, None, str] = UNSET,
) -> ListResponseIntegrationOut:
    """List Integrations

     List the application's integrations.

    Args:
        app_id (str): The app's ID or UID Example: unique-app-identifier.
        limit (Union[Unset, None, int]):
        iterator (Union[Unset, None, str]): The integ's ID Example:
            integ_1srOrx2ZWZBpBUvZwXKQmoEYga2.

    Returns:
        ListResponseIntegrationOut
    """

    kwargs = _get_kwargs(
        app_id=app_id,
        client=client,
        limit=limit,
        iterator=iterator,
    )

    kwargs["headers"] = {"svix-req-id": f"{random.getrandbits(32)}", **kwargs["headers"]}

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        retry_count = 0
        for retry in range(num_retries):
            response = await _client.request(**kwargs)
            if response.status_code >= 500 and retry < num_retries:
                retry_count += 1
                kwargs["headers"]["svix-retry-count"] = str(retry_count)
                sleep(sleep_time)
                sleep_time * 2
            else:
                break

    return _parse_response(response=response)


async def asyncio(
    app_id: str,
    *,
    client: AuthenticatedClient,
    limit: Union[Unset, None, int] = UNSET,
    iterator: Union[Unset, None, str] = UNSET,
) -> ListResponseIntegrationOut:
    """List Integrations

     List the application's integrations.

    Args:
        app_id (str): The app's ID or UID Example: unique-app-identifier.
        limit (Union[Unset, None, int]):
        iterator (Union[Unset, None, str]): The integ's ID Example:
            integ_1srOrx2ZWZBpBUvZwXKQmoEYga2.

    Returns:
        ListResponseIntegrationOut
    """

    return await asyncio_detailed(
        app_id=app_id,
        client=client,
        limit=limit,
        iterator=iterator,
    )
